@@ -55,14 +55,10 @@ from wradlib import georef, util, zonalstats
 class MissingSourcesError(Exception):
     """Is raised in case no source coordinates are available for interpolation."""
 
-    pass
-
 
 class MissingTargetsError(Exception):
     """Is raised in case no interpolation targets are available."""
 
-    pass
-
 
 class IpolBase:
     """
@@ -1579,7 +1575,8 @@ def interpolate_polar(data, mask=None, ipclass=Nearest):
     ranges = np.tile(np.arange(0.5, data.shape[1] + 0.5), data.shape[0])
     # construct the angles for every bin
     angles = np.repeat(
-        np.radians(np.arange(0, 360, 360.0 / data.shape[0])), data.shape[1]
+        np.radians(np.linspace(0, 360, endpoint=False, num=data.shape[0])),
+        data.shape[1],
     )
     # calculate cartesian coordinates for every bin
     binx = np.cos(angles) * ranges
@@ -1709,7 +1706,7 @@ Preprocessing-the-digitial-elevation-model`.
         yi = ny - (ny - 1) * (yi - cymin) / (cymax - cymin)
 
     # interpolation by map_coordinates
-    interp = ndimage.interpolation.map_coordinates(values, [yi, xi], **kwargs)
+    interp = ndimage.map_coordinates(values, [yi, xi], **kwargs)
     interp = interp.reshape(newshape)
 
     return interp
